summaryrefslogtreecommitdiffstats
path: root/test/big.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/big.c')
-rw-r--r--test/big.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/test/big.c b/test/big.c
index e6e2f86..7a3fd21 100644
--- a/test/big.c
+++ b/test/big.c
@@ -73,10 +73,10 @@
/* Define Small, Large, Extra Large, Huge File which
* corrspond to less than 2GB, 2GB, 4GB, and tens of GB file size.
* NOFILE stands for "no file" to be tested.
*/
-typedef enum fsizes_t { SFILE, LFILE, XLFILE, HUGEFILE, NOFILE} fsizes_t;
-fsizes_t file_size= NOFILE;
+typedef enum fsizes_t { SFILE, LFILE, XLFILE, HUGEFILE, NO_FILE} fsizes_t;
+fsizes_t file_size= NO_FILE;
const char *FILENAME[] = {
"big",
@@ -210,7 +210,7 @@ static fsizes_t
supports_big(void)
{
int fd = -1;
- fsizes_t fsize = NOFILE;
+ fsizes_t fsize = NO_FILE;
if((fd=HDopen("y.h5", O_RDWR|O_TRUNC|O_CREAT, 0666)) < 0)
goto error;
@@ -377,9 +377,9 @@ writer (char* filename, hid_t fapl, fsizes_t testsize, int wrt_n)
size2[0] /= 32;
break;
- case NOFILE:
+ case NO_FILE:
/* what to do?? */
- HDfprintf(stdout, "Unexpected file size of NOFILE\n");
+ HDfprintf(stdout, "Unexpected file size of NO_FILE\n");
goto error;
break;
@@ -599,7 +599,7 @@ test_sec2(hid_t fapl)
fsizes_t testsize;
testsize = supports_big();
- if(testsize == NOFILE) {
+ if(testsize == NO_FILE) {
HDfprintf(stdout, "Test for sec2 is skipped because file system does not support big files.\n");
goto quit;
}
@@ -634,7 +634,7 @@ test_stdio(hid_t fapl)
fsizes_t testsize;
testsize = supports_big();
- if(testsize == NOFILE) {
+ if(testsize == NO_FILE) {
HDfprintf(stdout, "Test for stdio is skipped because file system does not support big files.\n");
goto quit;
}
@@ -73,10 +73,10 @@
/* Define Small, Large, Extra Large, Huge File which
* corrspond to less than 2GB, 2GB, 4GB, and tens of GB file size.
- * NOFILE stands for "no file" to be tested.
+ * NO_FILE stands for "no file" to be tested.
*/